@@ -6,8 +6,8 @@
 // Copyright 2020  Pacien TRAN-GIRARD <pacien.trangirard@pacien.net>
 
 use crate::graph::{
-    Graph, GraphReadError, Leap, LeapType, Parents, Rank, Revision,
-    StableOrderGraph, NULL_REVISION,
+    Graph, GraphReadError, Leap, LeapType, Parents, Rank, RankedGraph,
+    Revision, StableOrderGraph, NULL_REVISION,
 };
 use crate::lazy_ancestors::LazyAncestors;
 use std::collections::HashSet;
@@ -47,7 +47,7 @@ pub fn merge_rank(
 /// This is an useful alternative to `rank` when the graph isn't yet built up
 /// to this node.
 pub fn node_rank(
-    graph: &impl Graph,
+    graph: &(impl Graph + RankedGraph),
     parents: &Parents,
 ) -> Result<Rank, GraphReadError> {
     let parent_rank = match parents {
@@ -369,8 +369,8 @@ mod tests {
         OrderedAncestorIterator,
     };
     use crate::graph::{
-        Graph, GraphReadError, LabelledGraph, MutableGraph, NodeID, Revision,
-        StableOrderGraph, NODE_ID_LEN, NULL_ID,
+        Graph, GraphReadError, LabelledGraph, MutableGraph, NodeID,
+        RankedGraph, Revision, StableOrderGraph, NODE_ID_LEN, NULL_ID,
     };
     use crate::testing::graph_in_mem::InMemoryGraph;
     use crate::testing::ordering::{
@@ -452,7 +452,7 @@ mod tests {
     }
 
     fn run_ordered_ancestors_iter(
-        graph: &(impl StableOrderGraph),
+        graph: &impl StableOrderGraph,
         rev: Revision,
     ) -> Result<Vec<Revision>, GraphReadError> {
         OrderedAncestorIterator::new(graph, rev)?.collect()
